@@ -1,29 +1,15 @@
 #
-# DESCRIPTION
+# DESCRIPTION:
 #   PerlORM - Object relational mapper (ORM) for Perl. PerlORM is Perl
 #   library that implements object-relational mapping. Its features are
 #   much similar to those of Java's Hibernate library, but interface is
 #   much different and easier to use.
 #
-# AUTHOR
+# AUTHOR:
 #   Alexey V. Akimov <akimov_alexey@sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2006 Alexey V. Akimov
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2.1 of the License, or (at your option) any later version.
-#   
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#   
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#   Copyright (c) 2005 Alexey V. Akimov. All rights reserved.
 #
 
 package ORM::Date;
@@ -34,14 +20,14 @@ use Carp;
 use POSIX;
 use ORM::Datetime;
 use overload
-        '>'   => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch >   $_[1]->epoch; },
-        '<'   => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch <   $_[1]->epoch; },
-        '>='  => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch >=  $_[1]->epoch; },
-        '<='  => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch <=  $_[1]->epoch; },
-        '=='  => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch ==  $_[1]->epoch; },
-        '!='  => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch !=  $_[1]->epoch; },
-        '<=>' => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch <=> $_[1]->epoch; },
-        'cmp' => sub { ( my $err = _check_args( @_ ) ); $err && croak $err; $_[0]->epoch cmp $_[1]->epoch; },
+        '>'   => sub { $_[0]->epoch >   $_[1]->epoch; },
+        '<'   => sub { $_[0]->epoch <   $_[1]->epoch; },
+        '>='  => sub { $_[0]->epoch >=  $_[1]->epoch; },
+        '<='  => sub { $_[0]->epoch <=  $_[1]->epoch; },
+        '=='  => sub { $_[0]->epoch ==  $_[1]->epoch; },
+        '!='  => sub { $_[0]->epoch !=  $_[1]->epoch; },
+        '<=>' => sub { $_[0]->epoch <=> $_[1]->epoch; },
+        'cmp' => sub { $_[0]->epoch cmp $_[1]->epoch; },
         'fallback' => 1;
 
 my $use_local_tz = 1;
@@ -74,11 +60,6 @@ sub new
         0,0,-1
     );
 
-    unless( defined $time )
-    {
-        croak "Specified time [".join( ',',@$array )."] cannot be represented";
-    }
-
     $class->new_epoch( $time );
 }
 
@@ -136,19 +117,8 @@ sub diff
     );
 }
 
-sub current
-{
-    my $class = shift;
-    my $date  = $class->new_epoch( time );
-    $class->new( [$date->year,$date->month,$date->mday,0,0,0] );
-}
-sub earlier24h
-{
-    my $class = shift;
-    my $date  = $class->new_epoch( time-24*60*60 );
-    $class->new( [$date->year,$date->month,$date->mday,0,0,0] );
-}
-
+sub current    { shift->new_epoch( time ); }
+sub earlier24h { shift->new_epoch( time-24*60*60 ); }
 sub date       { ORM::Date->new_epoch( $_[0]->epoch ); }
 sub datetime   { ORM::Datetime->new_epoch( $_[0]->epoch ); }
 
@@ -236,21 +206,4 @@ sub _tz_time_str
     return $use_local_tz ? localtime $time : gmtime $time;
 }
 
-sub _check_args
-{
-    my @arg = $_[2] ? ( $_[1], $_[0] ) : @_;
-    my $err = undef;
-
-    if( ! UNIVERSAL::isa( $arg[0], 'ORM::Date' ) )
-    {
-        $err = "First arg must be an 'ORM::Date' instance.";
-    }
-    elsif( ! UNIVERSAL::isa( $arg[1], 'ORM::Date' ) )
-    {
-        $err = "Second arg must be an 'ORM::Date' instance.";
-    }
-
-    $err;
-}
-
 1;
